@@ -8,10 +8,12 @@
 */
 
 /* .Call calls */
-extern SEXP KernelKnn_knn_index_dist_rcpp(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _KernelKnn_DIST_MATRIX_knn(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _KernelKnn_knn_index_dist_rcpp(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
-    {"KernelKnn_knn_index_dist_rcpp", (DL_FUNC) &KernelKnn_knn_index_dist_rcpp, 6},
+    {"_KernelKnn_DIST_MATRIX_knn",     (DL_FUNC) &_KernelKnn_DIST_MATRIX_knn,     6},
+    {"_KernelKnn_knn_index_dist_rcpp", (DL_FUNC) &_KernelKnn_knn_index_dist_rcpp, 6},
     {NULL, NULL, 0}
 };
 
@@ -20,4 +22,3 @@ void R_init_KernelKnn(DllInfo *dll)
     R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
     R_useDynamicSymbols(dll, FALSE);
 }
-
